#!/bin/sh
# Copyright 2018, Connectify, Inc. All Rights Reserved

#Speedify Generate Logs

echo "Generating Speedify Logs..."

TARGET_FILE=~/SpeedifyLogs.tar.gz
OPEN_PATH=1
SUBMIT_TO_DIRECTORY=0
REPORT_RESULT_TO_UI=0
MESSAGE=
EMAIL=
EXTRA_LOGS=/tmp/speedify-logs/

while getopts "osum:e:l:f:" opt; do
  case ${opt} in
    o )
      OPEN_PATH=0
      ;;
    s )
      SUBMIT_TO_DIRECTORY=1
      ;;
    u )
      REPORT_RESULT_TO_UI=1
      ;;
    m )
      MESSAGE=${OPTARG}
      ;;
    e )
      EMAIL=${OPTARG}
      ;;
    l )
      EXTRA_LOGS=${OPTARG}
      ;;
    f )
      TARGET_FILE=${OPTARG}
      ;;
    \? )
      echo "Invalid option: $OPTARG" 1>&2
      ;;
  esac
done

echo "Generating Speedify Logs..."

rm -r -f /tmp/SpeedifyLogs
rm -f "$TARGET_FILE"
mkdir /tmp/SpeedifyLogs
mkdir /tmp/SpeedifyLogs/SpeedifyLogs

echo "OS : Linux" > /tmp/SpeedifyLogs/SpeedifyLogs/OS.txt
echo "Kernel Release : $(uname -r)" >> /tmp/SpeedifyLogs/SpeedifyLogs/OS.txt
echo "Kernel Version : $(uname -v)" >> /tmp/SpeedifyLogs/SpeedifyLogs/OS.txt
echo "Arch :  $(uname -m)" >> /tmp/SpeedifyLogs/SpeedifyLogs/OS.txt
if command -v lsb_release > /dev/null 2>&1; then
  lsb_release -a >> /tmp/SpeedifyLogs/SpeedifyLogs/OS.txt
fi

touch /tmp/SpeedifyLogs/SpeedifyLogs/system.txt
if test -f /etc/issue; then
  if grep -q Raspbian /etc/issue; then
    vcgencmd measure_temp >> /tmp/SpeedifyLogs/SpeedifyLogs/system.txt
    vcgencmd get_throttled >> /tmp/SpeedifyLogs/SpeedifyLogs/system.txt
  fi
fi

if [ -d "/usr/share/speedify/logs/" ]; then
  cp -r /usr/share/speedify/logs/* /tmp/SpeedifyLogs/SpeedifyLogs/
fi
test -f /etc/speedify/speedify.conf && cp /etc/speedify/speedify.conf /tmp/SpeedifyLogs/SpeedifyLogs/

if command -v journalctl > /dev/null 2>&1; then
  journalctl -u speedify.service > /tmp/SpeedifyLogs/SpeedifyLogs/SpeedifyService.txt
  journalctl -u speedify-sharing.service > /tmp/SpeedifyLogs/SpeedifyLogs/SpeedifySharingService.txt
  journalctl -u dnsmasq.service > /tmp/SpeedifyLogs/SpeedifyLogs/DnsmasqService.txt
  journalctl -u hostapd.service > /tmp/SpeedifyLogs/SpeedifyLogs/HostapdService.txt
fi

test -f /etc/hostapd/hostapd.conf && cp /etc/hostapd/hostapd.conf /tmp/SpeedifyLogs/SpeedifyLogs/hostapd.conf
test -f /etc/dnsmasq.conf && cp /etc/dnsmasq.conf /tmp/SpeedifyLogs/SpeedifyLogs/dnsmasq.conf

if [ -d "/usr/share/speedifyui/logs/" ]; then
  cp -r /usr/share/speedifyui/logs/* /tmp/SpeedifyLogs/SpeedifyLogs/
fi

if [ -d "$EXTRA_LOGS" ]; then
  cp -r $EXTRA_LOGS/* /tmp/SpeedifyLogs/SpeedifyLogs/
fi

cd /tmp/SpeedifyLogs
tar -czvf "$TARGET_FILE" *
cd -

if command -v who > /dev/null 2>&1; then
  CURRENT_USER=$(who | awk 'NR==1{print $1}')
  chown $CURRENT_USER:$CURRENT_USER "$TARGET_FILE"
fi

rm -r /tmp/SpeedifyLogs

echo "Log files generated at $TARGET_FILE"


SUCCESS=0
if [ "$SUBMIT_TO_DIRECTORY" = "1" ]; then
  echo "Submitting logs to directory..."
  output=$(/usr/share/speedify/speedify_cli log report "$EMAIL" "$MESSAGE" "$TARGET_FILE")
  if [ $? -eq 0 ]; then
    echo "Logs submitted successfully"
    SUCCESS=1
    ticketId=$(echo $output | sed -n 's/.*"ticketId":\s*"\([^"]*\)".*/\1/p')
  else
    errorMessage=$(echo $output | sed -n 's/.*"errorMessage":\s*"\([^"]*\)".*/\1/p')
    echo "$errorMessage"
  fi
fi
if [ "$OPEN_PATH" = "1" -a "$SUCCESS" = "0" ]; then
  SUCCESS=1
  if command -v xdg-open > /dev/null 2>&1; then
    echo "Opening logs directory..."
    xdg-open ~/ &
  fi
fi
if [ "$REPORT_RESULT_TO_UI" = "1" ]; then
  if command -v xdg-open > /dev/null 2>&1; then
    echo "Reporting result to UI..."
    xdg-open speedify://speedify.com/in-app/log-report?success=${SUCCESS} &
  fi
fi
